#
# spec file for package libxcrypt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

%define major 1
%define libname %mklibname xcrypt %{major}
%define devellibname %mklibname xcrypt -d
%define staticlibname %mklibname xcrypt -d -s


Name:           libxcrypt
Version:        4.4.36
Release:        %mkrel 1
Summary:        Extended crypt library for DES, MD5, Blowfish and others
License:        GPL-3.0-or-later AND LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:            System/Libraries
URL:            https://github.com/besser82/%{name}
Source0:        https://github.com/besser82/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.xz

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  gcc
BuildRequires:  binutils

%description
libxcrypt is a modern library for one-way hashing of passwords.  It
supports DES, MD5, SHA-2-256, SHA-2-512, and bcrypt-based password
hashes, and provides the traditional Unix 'crypt' and 'crypt_r'
interfaces, as well as a set of extended interfaces pioneered by
Openwall Linux, 'crypt_rn', 'crypt_ra', 'crypt_gensalt',
'crypt_gensalt_rn', and 'crypt_gensalt_ra'.

%package -n %{libname}
Summary:        Extended crypt library for DES, MD5, Blowfish and others
License:        LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          System/Libraries

%description -n %{libname}
libxcrypt is a modern library for one-way hashing of passwords.  It
supports DES, MD5, SHA-2-256, SHA-2-512, and bcrypt-based password
hashes, and provides the traditional Unix 'crypt' and 'crypt_r'
interfaces, as well as a set of extended interfaces pioneered by
Openwall Linux, 'crypt_rn', 'crypt_ra', 'crypt_gensalt',
'crypt_gensalt_rn', and 'crypt_gensalt_ra'.

%package -n %{devellibname}
Summary:        Development files for %{name}
License:        LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/Libraries
Requires:       %{libname} = %{version}
Requires:       pkgconfig
Provides:       %{name}-devel = %{version}-%{release}
Provides:       xcrypt-devel = %{version}-%{release}

%description  -n %{devellibname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package  -n %{staticlibname}
Summary:        Static library for -static linking with %{name}
License:        GPL-3.0-or-later AND LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/Libraries
Requires:       %{devellibname} = %{version}
Requires:       glibc-static-devel

%description -n %{staticlibname}
This package contains the libxcrypt static libraries for -static
linking.  You don't need this, unless you link statically, which
is highly discouraged.


%prep
%setup -q
%apply_patches

%build
autoreconf -fiv
%configure2_5x           \
  --disable-silent-rules \
  --enable-shared        \
  --enable-static        \
  --enable-obsolete-api  \
  --enable-hashes=all    \
  --with-pkgconfigdir=%{_libdir}/pkgconfig
%make_build

%install
%make_install

find %{buildroot}%{_libdir} -name '*.la' -print -delete


%files -n %{libname}
%{_libdir}/libcrypt.so.%{major}*
%{_libdir}/libowcrypt.so.%{major}

%files -n %{devellibname}
%{_includedir}/crypt.h
%{_includedir}/xcrypt.h
%{_libdir}/libcrypt.so
%{_libdir}/libowcrypt.so
%{_libdir}/libxcrypt.so
%{_libdir}/pkgconfig/libcrypt.pc
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/crypt.3.*
%{_mandir}/man3/crypt_checksalt.3.*
%{_mandir}/man3/crypt_gensalt.3.*
%{_mandir}/man3/crypt_gensalt_ra.3.*
%{_mandir}/man3/crypt_gensalt_rn.3.*
%{_mandir}/man3/crypt_preferred_method.3.*
%{_mandir}/man3/crypt_r.3.*
%{_mandir}/man3/crypt_ra.3.*
%{_mandir}/man3/crypt_rn.3.*
%{_mandir}/man5/crypt.5.*

%files -n %{staticlibname}
%{_libdir}/libcrypt.a
%{_libdir}/libowcrypt.a
%{_libdir}/libxcrypt.a


%changelog
* Thu Jul 06 2023 tex - 4.4.36-1pclos2023
- new version

* Thu Jun 08 2023 tex - 4.4.35-1pclos2023
- new version

* Fri Nov 18 2022 tex - 4.4.32-1pclos2022
- new version

* Mon Nov 14 2022 tex - 4.4.31-1pclos2022
- new version

* Mon Oct 31 2022 tex - 4.4.29-1pclos2022
- new version

* Sun Feb 06 2022 tex - 4.4.28-1pclos2022
- new version

* Wed Jan 26 2022 tex - 4.4.27-2pclos2022
- rebuild against updates

* Sat Dec 18 2021 tex - 4.4.27-1pclos2021
- new version

* Sat Sep 18 2021 tex - 4.4.26-1pclos2021
- new version

* Mon Aug 09 2021 tex - 4.4.25-1pclos2021
- new version

* Thu Aug 05 2021 tex - 4.4.24-1pclos2021
- 4.4.24
